@@ -5,5 +5,7 @@ from motorengine.query.base import QueryOperator
 
 
 class LesserThanOrEqualQueryOperator(QueryOperator):
-    def to_query(self):
-        return {"$lte": self.value}
+    def to_query(self, field_name, value):
+        return {
+            field_name: {"$lte": value}
+        }
